package game.playState
{
	import flash.display.BitmapData;
	import flash.geom.Point;
	import flash.ui.Mouse;
	import flash.ui.MouseCursorData;
	
	import game.Assets;
	import game.Constants;
	
	import helper.MathHelper;
	
	import net.flashpunk.Entity;
	import net.flashpunk.graphics.Spritemap;
	import net.flashpunk.utils.Input;
	
	public class Cursor extends Entity
	{
		protected var spritemap:Spritemap;
		protected var playState:PlayState;
		protected var targetLookingDirection:Point;
		
		public function Cursor(playState:PlayState = null)
		{
			super();
			
			this.playState = playState;

			if (Constants.USE_NATIVE_CURSOR)
			{
				registerNativeCursor();
			}
			else
			{
				setupVirtualCursor();
			}
		}
		
		protected function registerNativeCursor():void
		{
			active = false;
			visible = false;
			
			var data:MouseCursorData = new MouseCursorData();
			data.data = new Vector.<BitmapData>();
			data.data.push((new Assets.CURSOR).bitmapData);
			data.frameRate = 0;
			data.hotSpot = Assets.CURSOR_HOTSPOT;
			
			Mouse.registerCursor("normal", data);
			Mouse.cursor = "normal";
		}
		
		protected function setupVirtualCursor():void
		{
			Mouse.hide();
			
			spritemap = new Spritemap(Assets.BULLET1, Assets.BULLET1_FRAMESIZE.x, Assets.BULLET1_FRAMESIZE.y);
			spritemap.originX = Assets.BULLET1_ORIGIN.x;
			spritemap.originY = Assets.BULLET1_ORIGIN.y;
			graphic = spritemap;
			
			spritemap.add("point", [0]);
			spritemap.add("click", [1]);
			
			targetLookingDirection = new Point();
			
			layer = Constants.LAYER_CURSOR;
		}

		override public function update():void
		{
			super.update();
			
			if (Input.mousePressedRight || Input.mousePressedMiddle)
			{
				Mouse.hide();
			}
		}
		
		override public function render():void
		{
			var mouseButtonClicked:Boolean = Input.mouseDown || Input.mouseDownMiddle || Input.mouseDownRight;
			spritemap.play(mouseButtonClicked ? "click" : "point");
			
			x = Input.mouseX;
			y = Input.mouseY;
			
			if (playState != null)
			{
				var player:Player = playState.player;
				
				targetLookingDirection.x = Input.mouseX - player.x;
				targetLookingDirection.y = Input.mouseY - player.y;
				
				spritemap.angle = MathHelper.directionToFPAngle(targetLookingDirection);
			}
			
			super.render();
		}
	}
}